listDeploymentJobs method
Returns a list of deployment jobs for a fleet. You can optionally provide filters to retrieve specific deployment jobs.
May throw ResourceNotFoundException. May throw InvalidParameterException. May throw InternalServerException. May throw ThrottlingException.
Parameter filters :
Optional filters to limit results.
The filter names status and fleetName are
supported. When filtering, you must use the complete value of the filtered
item. You can use up to three filters, but they must be for the same named
item. For example, if you are looking for items with the status
InProgress or the status Pending.
Parameter maxResults :
When this parameter is used, ListDeploymentJobs only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another
ListDeploymentJobs request with the returned
nextToken value. This value can be between 1 and 200. If this
parameter is not used, then ListDeploymentJobs returns up to
200 results and a nextToken value if applicable.
Parameter nextToken :
If the previous paginated request did not return all of the remaining
results, the response object's nextToken parameter value is
set to a token. To retrieve the next set of results, call
ListDeploymentJobs again and assign that token to the request
object's nextToken parameter. If there are no remaining
results, the previous response object's NextToken parameter is set to
null.
Implementation
Future<ListDeploymentJobsResponse> listDeploymentJobs({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateStringLength(
'nextToken',
nextToken,
1,
2048,
);
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listDeploymentJobs',
exceptionFnMap: _exceptionFns,
);
return ListDeploymentJobsResponse.fromJson(response);
}