listFleets method
Returns a list of fleets. You can optionally provide filters to retrieve specific fleets.
May throw ResourceNotFoundException. May throw InvalidParameterException. May throw InternalServerException. May throw ThrottlingException.
Parameter filters :
Optional filters to limit results.
The filter name name is supported. When filtering, you must
use the complete value of the filtered item. You can use up to three
filters.
Parameter maxResults :
When this parameter is used, ListFleets only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another ListFleets
request with the returned nextToken value. This value can be
between 1 and 200. If this parameter is not used, then
ListFleets returns up to 200 results and a
nextToken value if applicable.
Parameter nextToken :
If the previous paginated request did not return all of the remaining
results, the response object's nextToken parameter value is
set to a token. To retrieve the next set of results, call
ListFleets again and assign that token to the request
object's nextToken parameter. If there are no remaining
results, the previous response object's NextToken parameter is set to
null.
Implementation
Future<ListFleetsResponse> listFleets({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateStringLength(
'nextToken',
nextToken,
1,
2048,
);
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listFleets',
exceptionFnMap: _exceptionFns,
);
return ListFleetsResponse.fromJson(response);
}