listWorlds method
Lists worlds.
May throw InvalidParameterException. May throw ThrottlingException. May throw InternalServerException.
Parameter filters :
Optional filters to limit results. You can use status.
Parameter maxResults :
When this parameter is used, ListWorlds only returns
maxResults results in a single page along with a
nextToken response element. The remaining results of the
initial request can be seen by sending another ListWorlds
request with the returned nextToken value. This value can be
between 1 and 100. If this parameter is not used, then
ListWorlds returns up to 100 results and a
nextToken value if applicable.
Parameter nextToken :
If the previous paginated request did not return all of the remaining
results, the response object's nextToken parameter value is
set to a token. To retrieve the next set of results, call
ListWorlds again and assign that token to the request
object's nextToken parameter. If there are no remaining
results, the previous response object's NextToken parameter is set to
null.
Implementation
Future<ListWorldsResponse> listWorlds({
List<Filter>? filters,
int? maxResults,
String? nextToken,
}) async {
_s.validateStringLength(
'nextToken',
nextToken,
1,
2048,
);
final $payload = <String, dynamic>{
if (filters != null) 'filters': filters,
if (maxResults != null) 'maxResults': maxResults,
if (nextToken != null) 'nextToken': nextToken,
};
final response = await _protocol.send(
payload: $payload,
method: 'POST',
requestUri: '/listWorlds',
exceptionFnMap: _exceptionFns,
);
return ListWorldsResponse.fromJson(response);
}